# meet-man
### `meetman` : A simple Google Meet Client 

[![Downloads](https://static.pepy.tech/personalized-badge/lolacli?period=total&units=abbreviation&left_color=black&right_color=blue&left_text=Downloads)](https://pepy.tech/project/meet-man)


#### Dependencies
+ `PyQt5`
+ `PyQtWebEngine`

 
### Built with
+ `Python 3.8.5` 

![python](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/languages/python.svg)


## Installation

#### Method 2

If you have python and pip installed in your computer, execute the following

```bash
pip3 install meet-man
```

### Guide

- Open the app by typing `meet`

```
meet
```

## Developer Tools

- [Python 3.8.5](https://www.python.org/ftp/python/3.8.5/Python-3.8.5.tar.xz) 

![python](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/languages/python.svg)

- [Sublime Text 3](https://www.sublimetext.com/3)

- [Visual Studio Code](https://code.visualstudio.com) 

![vscode](https://raw.githubusercontent.com/MikeCodesDotNET/ColoredBadges/master/svg/dev/tools/visualstudio_code.svg)

- [Git](https://git-scm.com/) 

![git](https://raw.githubusercontent.com/klaasnicolaas/ColoredBadges/new-badges/svg/dev/tools/git.svg)

- [Python Poetry](https://python-poetry.org/) for package management and publishing

## Release Notes

- **Current Release- 0.1.1**

#### Developers
- [Arghya Sarkar](https://github.com/arghyagod-coder)

## License

License © 2021-Present Arghya Sarkar

This repository is licensed under the MIT license. See [LICENSE](https://github.com/arghyagod-coder/lola/master/LICENSE) for details.

## Special Notes

- Contribution is appreciated! Visit the contribution guide in [Contribution Guide](CONTRIBUTING.md)
- Thanks for seeing my project!